<?xml version="1.0"?>
<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<gui name="torrentactivity" version="7">
<MenuBar>
	<Menu name="view">
		<Action name="show_group_view" group="view_menu_top"/>
	</Menu>
	<Menu name="Torrents"><text>Torrents</text>
		<Action name="start" />
		<Action name="pause" />
		<Action name="stop" />
		<Action name="remove" />
		<Action name="view_remove_torrent_and_data" />
		<Separator/>
		<Action name="start_all"/>
		<Action name="stop_all"/>
		<Separator/>
		<Action name="check_data"/>
		<Action name="filter_torrent" />
		<Separator/>
		<Action name="queue_suspend" />
		<Separator/>
		<Action name="speed_limits"/>
	</Menu>
</MenuBar>

<Menu name="GroupsMenu"><text>Groups</text>
	<Action name="open_in_new_tab" />
	<Separator/>
	<Action name="new_group" />
	<Action name="edit_group_name" />
	<Action name="remove_group" />
	<Separator/>
	<Action name="edit_group_policy" />
	<Separator/>
	<Merge/>
</Menu>


<Menu name="ViewMenu"><text>View</text>
	<Action name="start" />
	<Action name="force_start" />
	<Action name="pause" />
	<Action name="stop" />
	<Action name="remove" />
	<Action name="view_remove_torrent_and_data" />
	<Separator/>
	<Action name="view_torrent_properties" />
	<Action name="view_announce" />
	<Action name="check_data" />
	<Action name="view_move_data" />
	<Action name="view_preview" />
	<Separator/>
	<Menu name="AdvancedMenu">
		<text>Advanced</text>
		<Action name="view_rename_torrent" />
		<Action name="view_export_torrent" />
		<Action name="view_copy_url" />
		<Action name="view_add_peers" />
		<Action name="speed_limits" />
		<Separator/>
		<Menu name="OpenDirMenu" icon="folder-open">
			<text>Open Directory</text>
			<Action name="view_open_data_dir" />
			<Action name="view_open_tmp_dir" />
		</Menu>
		<Action name="view_remove_from_group" />
		<Menu name="GroupsSubMenu" icon="application-x-bittorrent">
			<text>Add to Group</text>
			<ActionList name="view_groups_list" />
			<Separator/>
			<Action name="view_add_to_new_group" />
		</Menu>
	</Menu>
	<Separator/>
	<Menu name="ColumnsMenu">
		<text>Configure Columns</text>
		<title>Columns</title>
		<ActionList name="view_columns_list" />
	</Menu>
	<Merge/>
</Menu>

<ToolBar name="TorrentsToolBar" noMerge="1"><text>Torrents</text>
	<Action name="show_group_view" />
	<Separator/>
	<Action name="start"/>
	<Action name="pause" />
	<Action name="stop"/>
	<Action name="remove"/>
	<Action name="start_all"/>
	<Action name="stop_all"/>
	<Separator/>
	<Action name="queue_suspend" />
</ToolBar>

</gui>
