<?xml version="1.0"?>
<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<gui name="ktorrent" version="23">
<MenuBar>
  <Menu name="file"><text>&amp;File</text>
	  <Action name="file_new"/>
	  <Action name="file_open"/>
	  <Action name="file_open_silently"/>
	  <Action name="paste_url"/>
	  <Separator/>
	  <Action name="import" />
	  <Separator/>
	  <Action name="ipfilter_action"/>
	  <Merge/>
  </Menu>
  <Menu name="view"><text>&amp;View</text>
	<Merge/>
	<Separator/>
	<ActionList name="activities_list" />
  </Menu>
  <Merge/>
</MenuBar>


<ToolBar name="mainToolBar" noMerge="1"><text>Main</text>
	<ActionList name="activities_list" />
	<Separator/>
	<Action name="file_new"/>
    <Action name="file_open"/>
	<Action name="paste_url"/>
	<Action name="ipfilter_action"/>
</ToolBar>
</gui>
